@@ -1,8 +1,9 @@
 import inspect
 import random
+import re
 
-from NewLifeUtils.FileModule import get_files_from_dir
 from NewLifeUtils.LoggerModule import *
+from NewLifeUtils.StringUtilModule import parse_args
 
 
 def select_rand_list(source, use_zero=False):
@@ -78,8 +79,8 @@ def bprint(text, maxlinelength=9, font="default"):
 
 
 def format_number(
-        number=random.randrange(1111111111111111, 9999999999999999),
-        numform="4444",
+    number=random.randrange(1111111111111111, 9999999999999999),
+    numform="4444",
 ):
     # A total conversion
     number = int(number)
@@ -103,15 +104,30 @@ def format_number(
     result = str(number)
     shift = 0
     for pos in numform:
-        result = result[: int(pos) + shift] + " " + result[int(pos) + shift:]
+        result = result[: int(pos) + shift] + " " + result[int(pos) + shift :]
         shift += int(pos) + 1
     return result
 
+def safe_format(text, keys=None, func = None, smart=None):
+    if keys is None:
+        keys = {}
+    if smart is None:
+        smart = {}
 
-def safe_format(text, keys):
     class SafeDict(dict):
         def __missing__(self, key):
-            return '{' + key + '}'
+            nonlocal func
+            if smart is not {}:
+                keypr = parse_args(key)
+                name = keypr['command']
+                if name not in smart.keys():
+                    return "{" + key + "}"
+                else:
+                    return smart[name](*keypr['param'])
+            elif func is not None:
+                return "{" + str(func(key)) + "}"
+            else:
+                return "{" + key + "}"
 
     return text.format_map(SafeDict(**keys))
 
@@ -122,3 +138,26 @@ def set_seed_formated(seed=-1):
     processed_seed = int("".join(seed.split()))
     random.seed = processed_seed
     return processed_seed
+
+
+def hex_to_rgb(hx, hsl=False):
+    """Converts a HEX code into RGB or HSL.
+    Args:
+        hx (str): Takes both short as well as long HEX codes.
+        hsl (bool): Converts the given HEX code into HSL value if True.
+    Return:
+        Tuple of length 3 consisting of either int or float values.
+    Raise:
+        ValueError: If given value is not a valid HEX code."""
+    if re.compile(r"#[a-fA-F0-9]{3}(?:[a-fA-F0-9]{3})?$").match(hx):
+        div = 255.0 if hsl else 0
+        if len(hx) <= 4:
+            return tuple(
+                int(hx[i] * 2, 16) / div if div else int(hx[i] * 2, 16)
+                for i in (1, 2, 3)
+            )
+        return tuple(
+            int(hx[i : i + 2], 16) / div if div else int(hx[i : i + 2], 16)
+            for i in (1, 3, 5)
+        )
+    raise ValueError(f'"{hx}" is not a valid HEX code.')
